@@ -1,3 +1,6 @@
+"""Tools for managing OS errors.
+"""
+
 from __future__ import print_function
 from __future__ import unicode_literals
 
@@ -15,7 +18,8 @@ _WINDOWS_PLATFORM = platform.system() == 'Windows'
 
 
 class _ConvertOSErrors(object):
-    """Context manager to convert OSErrors in to FS Errors."""
+    """Context manager to convert OSErrors in to FS Errors.
+    """
 
     FILE_ERRORS = {
         64: errors.RemoteConnectionError,  # ENONET
@@ -84,8 +88,9 @@ convert_os_errors = _ConvertOSErrors
 
 @contextmanager
 def unwrap_errors(path_replace):
-    """
-    A context manager to re-write the paths in resource exceptions to be
+    """Get a context to map OS errors to their `fs.errors` counterpart.
+
+    The context will re-write the paths in resource exceptions to be
     in the same context as the wrapped filesystem.
 
     The only parameter may be the path from the parent, if only one path
