@@ -1,3 +1,6 @@
+"""Least Recently Used cache mapping.
+"""
+
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
@@ -17,14 +20,16 @@ class LRUCache(OrderedDict):
         super(LRUCache, self).__init__()
 
     def __setitem__(self, key, value):
-        """Store a new views, potentially discarding an old value."""
+        """Store a new views, potentially discarding an old value.
+        """
         if key not in self:
             if len(self) >= self.cache_size:
                 self.popitem(last=False)
         OrderedDict.__setitem__(self, key, value)
 
     def __getitem__(self, key):
-        """Gets the item, but also makes it most recent."""
+        """Get the item, but also makes it most recent.
+        """
         _super = super(LRUCache, self)
         value = _super.__getitem__(key)
         _super.__delitem__(key)
