@@ -1,11 +1,5 @@
 # coding: utf-8
-"""
-fs.opener.registry
-===================
-
-Defines the Registry, which maps protocols and FS URLs to their
-respective Opener.
-
+"""`Registry` class mapping protocols and FS URLs to their `Opener`.
 """
 
 from __future__ import absolute_import
@@ -22,19 +16,16 @@ from .parse import parse_fs_url
 
 
 class Registry(object):
+    """A registry for `Opener` instances.
     """
-    A registry for `Opener` instances.
-
-    """
-
 
     def __init__(self, default_opener='osfs'):
-        """
-        Create a registry object.
+        """Create a registry object.
 
-        :param default_opener: The protocol to use, if one is not
-            supplied. The default is to use 'osfs', so that the FS URL
-            is treated as a system path if no protocol is given.
+        Arguments:
+            default_opener (str, optional): The protocol to use, if one
+                is not supplied. The default is to use 'osfs', so that the
+                FS URL is treated as a system path if no protocol is given.
 
         """
         self.default_opener = default_opener
@@ -46,7 +37,8 @@ class Registry(object):
 
     @property
     def protocols(self):
-        """A list of supported protocols."""
+        """`list`: the list of supported protocols.
+        """
         if self._protocols is None:
             self._protocols = [
                 entry_point.name
@@ -56,16 +48,20 @@ class Registry(object):
         return self._protocols
 
     def get_opener(self, protocol):
-        """
-        Get the opener class associated to a given protocol.
+        """Get the opener class associated to a given protocol.
 
-        :param str protocol: A filesystem protocol.
-        :rtype: ``Opener``.
-        :raises `~fs.opener.errors.UnsupportedProtocol`: If no opener
-            could be found.
-        :raises `EntryPointLoadingError`: If the returned entry
-            point is not an ``Opener`` subclass or could not be loaded
-            successfully.
+        Arguments:
+            protocol (str): A filesystem protocol.
+
+        Returns:
+            Opener: an opener instance.
+
+        Raises:
+            ~fs.opener.errors.UnsupportedProtocol: If no opener
+                could be found for the given protocol.
+            EntryPointLoadingError: If the returned entry point
+                is not an `Opener` subclass or could not be loaded
+                successfully.
 
         """
         protocol = protocol or self.default_opener
@@ -112,21 +108,23 @@ class Registry(object):
              create=False,
              cwd=".",
              default_protocol='osfs'):
-        """
-        Open a filesystem from a FS URL. Returns a tuple of a filesystem
-        object and a path. If there is no path in the FS URL, the path
-        value will be ``None``.
+        """Open a filesystem from a FS URL.
 
-        :param str fs_url: A filesystem URL
-        :param bool writeable: True if the filesystem must be writeable.
-        :param bool create: True if the filesystem should be created if
-            it does not exist.
-        :param cwd: The current working directory.
-        :type cwd: str or None
-        :rtype: Tuple of ``(<filesystem>, <path from url>)``
+        Returns a tuple of a filesystem object and a path. If there is
+        no path in the FS URL, the path value will be `None`.
+
+        Arguments:
+            fs_url (str): A filesystem URL.
+            writeable (bool, optional): `True` if the filesystem must be
+                writeable.
+            create (bool, optional): `True` if the filesystem should be
+                created if it does not exist.
+            cwd (str, optional): The current working directory, or `None`.
+
+        Returns:
+            (FS, str): a tuple of ``(<filesystem>, <path from url>)``
 
         """
-
         if '://' not in fs_url:
             # URL may just be a path
             fs_url = "{}://{}".format(default_protocol, fs_url)
@@ -148,23 +146,25 @@ class Registry(object):
 
     def open_fs(self,
                 fs_url,
-                writeable=True,
+                writeable=False,
                 create=False,
                 cwd=".",
                 default_protocol='osfs'):
-        """
-        Open a filesystem object from a FS URL (ignoring the path
-        component).
+        """Open a filesystem from a FS URL (ignoring the path component).
 
-        :param str fs_url: A filesystem URL.
-        :param bool writeable: True if the filesystem must be writeable.
-        :param bool create: True if the filesystem should be created if
-            it does not exist.
-        :param str cwd: The current working directory (generally only
-            relevant for OS filesystems).
-        :param str default_protocol: The protocol to use if one is not
-            supplied in the FS URL (defaults to ``"osfs"``).
-        :returns: :class:`~fs.base.FS` object
+        Arguments:
+            fs_url (str): A filesystem URL.
+            writeable (bool, optional): `True` if the filesystem must
+                be writeable.
+            create (bool, optional): `True` if the filesystem should be
+                created if it does not exist.
+            cwd (str, optional): The current working directory (generally
+                only relevant for OS filesystems).
+            default_protocol (str): The protocol to use if one is not
+                supplied in the FS URL (defaults to ``"osfs"``).
+
+        Returns:
+            ~fs.base.FS: A filesystem instance.
 
         """
         from ..base import FS
@@ -181,42 +181,40 @@ class Registry(object):
         return _fs
 
     @contextlib.contextmanager
-    def manage_fs(self, fs_url, create=False, writeable=True, cwd='.'):
-        '''
-        A context manager opens / closes a filesystem.
+    def manage_fs(self, fs_url, create=False, writeable=False, cwd='.'):  # noqa: D300,D301
+        """Get a context manager to open and close a filesystem.
 
-        :param fs_url: A FS instance or a FS URL.
-        :type fs_url: str or FS
-        :param bool create: If ``True``, then create the filesystem if
-            it doesn't already exist.
-        :param bool writeable: If ``True``, then the filesystem should
-            be writeable.
-        :param str cwd: The current working directory, if opening a
-            :class:`~fs.osfs.OSFS`.
+        Arguments:
+            fs_url (FS or str): A filesystem instance or a FS URL.
+            create (bool, optional): If `True`, then create the filesystem if
+                it doesn't already exist.
+            writeable (bool, optional): If `True`, then the filesystem
+                must be writeable.
+            cwd (str): The current working directory, if opening a
+                `~fs.osfs.OSFS`.
 
         Sometimes it is convenient to be able to pass either a FS object
         *or* an FS URL to a function. This context manager handles the
         required logic for that.
 
-        Here's an example::
+        Example:
+            >>> def print_ls(list_fs):
+            ...     \"\"\"List a directory.\"\"\"
+            ...     with manage_fs(list_fs) as fs:
+            ...         print(' '.join(fs.listdir()))
 
-            def print_ls(list_fs):
-                """List a directory."""
-                with manage_fs(list_fs) as fs:
-                    print(" ".join(fs.listdir()))
+            This function may be used in two ways. You may either pass
+            a ``str``, as follows::
 
-        This function may be used in two ways. You may either pass
-        either a ``str``, as follows::
+                >>> print_list('zip://projects.zip')
 
-            print_list('zip://projects.zip')
+            Or, an filesystem instance::
 
-        Or, an FS instance::
+                >>> from fs.osfs import OSFS
+                >>> projects_fs = OSFS('~/')
+                >>> print_list(projects_fs)
 
-            from fs.osfs import OSFS
-            projects_fs = OSFS('~/')
-            print_list(projects_fs)
-
-        '''
+        """
         from ..base import FS
         if isinstance(fs_url, FS):
             yield fs_url
